<?php

declare(strict_types=1);

namespace Drupal\Tests\micronode_block\Functional;

use Drupal\node\Entity\Node;
use Drupal\Tests\BrowserTestBase;

/**
 * Tests installing the module.
 *
 * This is very simple test of schema, dependencies, and the deriver.
 *
 * @group micronode_block
 */
class MicronodeBlockTest extends BrowserTestBase {

  /**
   * {@inheritdoc}
   */
  protected static $modules = [
    'micronode_block_test',
  ];

  /**
   * {@inheritdoc}
   */
  protected $defaultTheme = 'stark';

  /**
   * Tests that Micronode Block installs and its deriver works.
   **/
  public function testMicronodeBlockDeriver() {
    $definitions = \Drupal::service('plugin.manager.block')->getDefinitions();
    $this->assertFalse(isset($definitions['micronode_block:one']));
    $this->assertNotEmpty($definitions['micronode_block:two']);
    $this->assertNotEmpty($definitions['micronode_block:three']);

    // Test dependencies.
    $two = Node::create([
      'type' => 'two',
      'title' => 'Two',
    ]);
    $two->save();
    $block = \Drupal::service('plugin.manager.block')->createInstance(
      'micronode_block:two',
      ['nid' => $two->id()],
    );
    $expected = [
      'content' => [$two->getConfigDependencyName()],
    ];
    $this->assertSame($expected, $block->calculateDependencies());
  }

}
